@@ -90,6 +90,7 @@ class iMeshDashboard:
             return json.dumps(self.myNodeInfo)
         except Exception as e:
             traceback.print_exc()
+            print(self.myNodeInfo)
             return None
     
     
@@ -136,9 +137,9 @@ class iMeshDashboard:
             #print(packet)
             hop = packet.get('hopLimit', None)
             #print(hop)
-            if (hop is not None) and (myNodeInfo['user']['id'] != packet.get('fromId')):
+            if (hop is not None) and (self.myNodeInfo['user']['id'] != packet.get('fromId')):
                 print("Pushing received node info")
-                client.publish("meshInfo/hopInfo", json.dumps({"receivedNode":packet.get('fromId'), "receiverNode":myNodeInfo['user']['id'],
+                self.client.publish("meshInfo/hopInfo", json.dumps({"receivedNode":packet.get('fromId'), "receiverNode":self.myNodeInfo['user']['id'],
                                "hopLimit":packet.get('hopLimit'), "rxTime":packet.get('rxTime')}))
                               
         try:
@@ -157,6 +158,7 @@ class iMeshDashboard:
                             self.client.publish("receivedNodes/"+node, json.dumps(self.stripKey(nodeValue, "raw")))
                 except Exception as e:
                     traceback.print_exc()
+                    print(nodeValue)
         except Exception as e:
             traceback.print_exc()
         finally:
